{% extends 'smartshare/base.html' %}
{% block title %}Shared Locations{% endblock %}
{% block body %}

    <div class="container">
        <br>
        <div class="card">
            <div class="card-header d-flex justify-content-between">
                <span>Shared Locations</span>
                <span style="height: 25px">{{ user }}</span>
            </div>
            <div class="list-group-flush">
                {% for location in locations %}
                    <a class="list-group-item" href="{% url 'location_detail' location.path %}">{{ location.path }}</a>
                {% endfor %}
            </div>
        </div>
    </div>
{% endblock %}