# Generated by Django 2.0.8 on 2018-10-01 12:41

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Location',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('path', models.CharField(max_length=300)),
                ('active_p', models.BooleanField(default=True, verbose_name='Active')),
                ('show_f_p', models.BooleanField(default=True, verbose_name='Show Files')),
                ('show_d_p', models.BooleanField(default=True, verbose_name='Show Directories')),
                ('show_h_f_p', models.BooleanField(default=False, verbose_name='Show Hidden Files')),
                ('show_h_d_p', models.BooleanField(default=False, verbose_name='Show Hidden Directories')),
                ('can_down_p', models.BooleanField(default=False, verbose_name='Can Download')),
                ('can_up_p', models.BooleanField(default=False, verbose_name='Can Upload')),
                ('can_del_p', models.BooleanField(default=False, verbose_name='Can Delete')),
                ('can_crt_p', models.BooleanField(default=False, verbose_name='Can Create')),
                ('can_run_p', models.BooleanField(default=False, verbose_name='Can Run Command')),
                ('active_u', models.BooleanField(default=True, verbose_name='Active')),
                ('show_f_u', models.BooleanField(default=True, verbose_name='Show Files')),
                ('show_d_u', models.BooleanField(default=True, verbose_name='Show Directories')),
                ('show_h_f_u', models.BooleanField(default=False, verbose_name='Show Hidden Files')),
                ('show_h_d_u', models.BooleanField(default=False, verbose_name='Show Hidden Directories')),
                ('can_down_u', models.BooleanField(default=True, verbose_name='Can Download')),
                ('can_up_u', models.BooleanField(default=True, verbose_name='Can Upload')),
                ('can_del_u', models.BooleanField(default=False, verbose_name='Can Delete')),
                ('can_crt_u', models.BooleanField(default=True, verbose_name='Can Create')),
                ('can_run_u', models.BooleanField(default=False, verbose_name='Can Run Command')),
                ('active_a', models.BooleanField(default=True, verbose_name='Active')),
                ('show_f_a', models.BooleanField(default=True, verbose_name='Show Files')),
                ('show_d_a', models.BooleanField(default=True, verbose_name='Show Directories')),
                ('show_h_f_a', models.BooleanField(default=True, verbose_name='Show Hidden Files')),
                ('show_h_d_a', models.BooleanField(default=True, verbose_name='Show Hidden Directories')),
                ('can_down_a', models.BooleanField(default=True, verbose_name='Can Download')),
                ('can_up_a', models.BooleanField(default=True, verbose_name='Can Upload')),
                ('can_del_a', models.BooleanField(default=True, verbose_name='Can Delete')),
                ('can_crt_a', models.BooleanField(default=True, verbose_name='Can Create')),
                ('can_run_a', models.BooleanField(default=True, verbose_name='Can Run Command')),
            ],
        ),
    ]
