{% extends 'smartshare/base.html' %}
{% block title %}404{% endblock %}
{% block body_tag %}class="bg-secondary"{% endblock %}
{% block body %}
        <div class="container d-flex h-100 justify-content-center">
            <div class="card bg-dark align-self-center w-75 text-center text-white">
                <div class="card-body">
                    <h1 class="card-title">404</h1>
                </div>
            </div>
        </div>
{% endblock %}