__title__ = 'django smart share'
__version__ = '0.8.8'
__author__ = 'Abolfazl Amiri'
__author_email__ = 'aa.smpro@gmail.com'
__license__ = 'GNU General Public License v3 (GPLv3)'
__description__ = F"""django smart share {__version__}
simple django app for sharing files over http / https.
"""
